==> brmo-stufbg204-1.6.3p1-sources.jar: nl/egem/stuf/sector/bg/_0204/NNPKennisgeving.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Niet natuurlijk persoon binnen kennisgeving
 * 
 * <p>Java class for NNP-kennisgeving complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NNP-kennisgeving">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund">
 *       &lt;sequence>
 *         &lt;element name="NNPADRCOR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens" minOccurs="0"/>
 *         &lt;element name="NNPADRVBL" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens" minOccurs="0"/>
 *         &lt;element name="NNPNNPHFD" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="NNPNNPNVN" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NNP-kennisgeving", propOrder = {
    "nnpadrcor",
    "nnpadrvbl",
    "nnpnnphfd",
    "nnpnnpnvn"
})
public class NNPKennisgeving
    extends NNPFund
{

    @XmlElementRef(name = "NNPADRCOR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelKerngegevens> nnpadrcor;
    @XmlElementRef(name = "NNPADRVBL", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelKerngegevens> nnpadrvbl;
    @XmlElementRef(name = "NNPNNPHFD", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NNPKennisgeving.NNPNNPHFD> nnpnnphfd;
    @XmlElement(name = "NNPNNPNVN", nillable = true)
    protected List<NNPKennisgeving.NNPNNPNVN> nnpnnpnvn;

    /**
     * Gets the value of the nnpadrcor property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public JAXBElement<ADRRelKerngegevens> getNNPADRCOR() {
        return nnpadrcor;
    }

    /**
     * Sets the value of the nnpadrcor property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public void setNNPADRCOR(JAXBElement<ADRRelKerngegevens> value) {
        this.nnpadrcor = value;
    }

    /**
     * Gets the value of the nnpadrvbl property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public JAXBElement<ADRRelKerngegevens> getNNPADRVBL() {
        return nnpadrvbl;
    }

    /**
     * Sets the value of the nnpadrvbl property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public void setNNPADRVBL(JAXBElement<ADRRelKerngegevens> value) {
        this.nnpadrvbl = value;
    }

    /**
     * Gets the value of the nnpnnphfd property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NNPKennisgeving.NNPNNPHFD }{@code >}
     *     
     */
    public JAXBElement<NNPKennisgeving.NNPNNPHFD> getNNPNNPHFD() {
        return nnpnnphfd;
    }

    /**
     * Sets the value of the nnpnnphfd property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NNPKennisgeving.NNPNNPHFD }{@code >}
     *     
     */
    public void setNNPNNPHFD(JAXBElement<NNPKennisgeving.NNPNNPHFD> value) {
        this.nnpnnphfd = value;
    }

    /**
     * Gets the value of the nnpnnpnvn property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpnnpnvn property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPNNPNVN().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPKennisgeving.NNPNNPNVN }
     * 
     * 
     */
    public List<NNPKennisgeving.NNPNNPNVN> getNNPNNPNVN() {
        if (nnpnnpnvn == null) {
            nnpnnpnvn = new ArrayList<NNPKennisgeving.NNPNNPNVN>();
        }
        return this.nnpnnpnvn;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPHFD
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKerngegevens> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public JAXBElement<NNPKerngegevens> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKerngegevens> value) {
            this.nnp = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPNVN
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKerngegevens> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public JAXBElement<NNPKerngegevens> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKerngegevens> value) {
            this.nnp = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/NNPKennisgeving.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * Niet natuurlijk persoon binnen kennisgeving
 * 
 * <p>Java class for NNP-kennisgeving complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NNP-kennisgeving"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}NNP-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="NNPADRCOR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens" minOccurs="0"/&gt;
 *         &lt;element name="NNPADRVBL" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens" minOccurs="0"/&gt;
 *         &lt;element name="NNPNNPHFD" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="NNPNNPNVN" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NNP-kennisgeving", propOrder = {
    "nnpadrcor",
    "nnpadrvbl",
    "nnpnnphfd",
    "nnpnnpnvn"
})
public class NNPKennisgeving
    extends NNPFund
{

    @XmlElementRef(name = "NNPADRCOR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelKerngegevens> nnpadrcor;
    @XmlElementRef(name = "NNPADRVBL", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelKerngegevens> nnpadrvbl;
    @XmlElementRef(name = "NNPNNPHFD", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NNPKennisgeving.NNPNNPHFD> nnpnnphfd;
    @XmlElement(name = "NNPNNPNVN", nillable = true)
    protected List<NNPKennisgeving.NNPNNPNVN> nnpnnpnvn;

    /**
     * Gets the value of the nnpadrcor property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public JAXBElement<ADRRelKerngegevens> getNNPADRCOR() {
        return nnpadrcor;
    }

    /**
     * Sets the value of the nnpadrcor property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public void setNNPADRCOR(JAXBElement<ADRRelKerngegevens> value) {
        this.nnpadrcor = value;
    }

    /**
     * Gets the value of the nnpadrvbl property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public JAXBElement<ADRRelKerngegevens> getNNPADRVBL() {
        return nnpadrvbl;
    }

    /**
     * Sets the value of the nnpadrvbl property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public void setNNPADRVBL(JAXBElement<ADRRelKerngegevens> value) {
        this.nnpadrvbl = value;
    }

    /**
     * Gets the value of the nnpnnphfd property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NNPKennisgeving.NNPNNPHFD }{@code >}
     *     
     */
    public JAXBElement<NNPKennisgeving.NNPNNPHFD> getNNPNNPHFD() {
        return nnpnnphfd;
    }

    /**
     * Sets the value of the nnpnnphfd property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NNPKennisgeving.NNPNNPHFD }{@code >}
     *     
     */
    public void setNNPNNPHFD(JAXBElement<NNPKennisgeving.NNPNNPHFD> value) {
        this.nnpnnphfd = value;
    }

    /**
     * Gets the value of the nnpnnpnvn property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nnpnnpnvn property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNNPNNPNVN().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link NNPKennisgeving.NNPNNPNVN }
     * 
     * 
     */
    public List<NNPKennisgeving.NNPNNPNVN> getNNPNNPNVN() {
        if (nnpnnpnvn == null) {
            nnpnnpnvn = new ArrayList<NNPKennisgeving.NNPNNPNVN>();
        }
        return this.nnpnnpnvn;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPHFD
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKerngegevens> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public JAXBElement<NNPKerngegevens> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKerngegevens> value) {
            this.nnp = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens" minOccurs="0"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp"
    })
    public static class NNPNNPNVN
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKerngegevens> nnp;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public JAXBElement<NNPKerngegevens> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKerngegevens> value) {
            this.nnp = value;
        }

    }

}
